@@ -54,7 +54,6 @@ ATTR_ITEM_CATEGORY = 'categoryId'
 ATTR_COMMAND = 'command'
 ATTR_TEAM_ID = 'teamId'
 
-
 # properties of returned data
 PROP_LIST = 'list'
 PROP_ITEMS = 'items'
@@ -62,8 +61,7 @@ PROP_ITEMS = 'items'
 
 def add_crossed_off_prop(item):
     """Adds crossed off prop to any items that don't have it."""
-    if not hasattr(item, ATTR_ITEM_CROSSED):
-        item[ATTR_ITEM_CROSSED] = False
+    item[ATTR_ITEM_CROSSED] = item.get(ATTR_ITEM_CROSSED, False)
     return item
 
 
@@ -111,7 +109,6 @@ class OurGroceries():
                 self._category_id = re.findall(REGEX_CATEGORY_ID, responseText)[0]
                 _LOGGER.debug('ourgroceries found category_id {}'.format(self._category_id))
 
-
     async def get_my_lists(self):
         """Get our grocery lists."""
         _LOGGER.debug('ourgroceries get_my_lists')
